Stan Math Library: stan/math/prim/arr/err/check_nonzero_size.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
check_nonzero_size.hpp File Reference
`#include <stan/math/prim/scal/err/invalid_argument.hpp>`
`#include <string>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T_y >
bool | stan::math::check_nonzero_size (const char *function, const char *name, const T_y &y)
| Return `true` if the specified matrix/vector is of non-zero size. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.